@@ -46,7 +46,8 @@ config_default = [
                 "dont_show_thread_progress": False,
                 "dont_show_domain_progress": False,
                 "dont_show_album_progress": False,
-                "dont_show_file_progress": False
+                "dont_show_file_progress": False,
+                "refresh_rate": 10
             },
             "Ratelimiting": {
                 "connection_timeout": 15,
@@ -96,12 +97,12 @@ jdownloader_args = ["apply_jdownloader", "jdownloader_username", "jdownloader_pa
 
 progress_args = ["hide_new_progress", "dont_show_overall_progress", "dont_show_forum_progress",
                  "dont_show_thread_progress", "dont_show_domain_progress", "dont_show_album_progress",
-                 "dont_show_file_progress"]
+                 "dont_show_file_progress", "refresh_rate"]
 
 ratelimiting_args = ["connection_timeout", "ratelimit", "throttle"]
 
 runtime_args = ["simultaneous_downloads_per_domain", "allow_insecure_connections", "attempts", "disable_attempt_limit",
                 "include_id", "skip_download_mark_completed", "proxy", "required_free_space", "output_errored_urls",
-                "output_unsupported_urls", "block_sub_folders"]
+                "output_unsupported_urls", "block_sub_folders", "remove_bunkr_identifier"]
 
 sorting_args = ["sort_downloads", "sort_directory", "sorted_audio", "sorted_images", "sorted_others", "sorted_videos"]
