@@ -2,17 +2,30 @@ from __future__ import annotations
 
 import asyncio
 import re
+from pathlib import Path
 
+import aiofiles
 from bs4 import BeautifulSoup
 from yarl import URL
 
-from ..base_functions.base_functions import log, make_title_safe, write_last_post_file, get_filename_and_ext, logger
+from ..base_functions.base_functions import (
+    get_filename_and_ext,
+    log,
+    logger,
+    make_title_safe,
+)
 from ..base_functions.data_classes import CascadeItem, MediaItem
 from ..base_functions.error_classes import FailedLoginFailure, NoExtensionFailure
 from ..base_functions.sql_helper import SQLHelper
 from ..client.client import ScrapeSession
 
 
+async def write_last_post_file(file: Path, url: str):
+    """Writes the last post url from a thread to the specified file"""
+    async with aiofiles.open(file, mode='a') as f:
+        await f.write(url + '\n')
+
+
 class ForumLogin:
     def __init__(self, name: str, username: str, password: str):
         self.name = name
@@ -181,7 +194,7 @@ class XenforoCrawler:
                     filename, ext = await get_filename_and_ext(link.name, True)
                 except NoExtensionFailure:
                     continue
-                media = MediaItem(link, url, completed, filename, ext)
+                media = MediaItem(link, url, completed, filename, ext, filename)
                 await cascade.add_to_album(domain, in_prog_title, media)
         return content_links
 
@@ -419,4 +432,4 @@ class XenforoCrawler:
                 else:
                     last_post_url = url / post_num_str
                 await write_last_post_file(self.output_last_file, str(last_post_url))
-        return title
\ No newline at end of file
+        return title
